@@ -118,6 +118,8 @@ pub fn run(args: &ArgMatches) -> Result<(), Error> {
             mapper,
             since: None,
             intersect,
+            retry_policy: None,
+            finalize: None,
         }),
         PeerMode::AsClient => DumpSource::N2C(N2CConfig {
             address: AddressArg(bearer, socket),
@@ -127,6 +129,7 @@ pub fn run(args: &ArgMatches) -> Result<(), Error> {
             mapper,
             since: None,
             intersect,
+            retry_policy: None,
         }),
     };
 
@@ -158,3 +161,34 @@ pub fn run(args: &ArgMatches) -> Result<(), Error> {
 
     Ok(())
 }
+
+/// Creates the clap definition for this sub-command
+pub(crate) fn command_definition<'a>() -> clap::Command<'a> {
+    clap::Command::new("dump")
+        .arg(clap::Arg::new("socket").required(true))
+        .arg(
+            clap::Arg::new("bearer")
+                .long("bearer")
+                .takes_value(true)
+                .possible_values(&["tcp", "unix"]),
+        )
+        .arg(clap::Arg::new("magic").long("magic").takes_value(true))
+        .arg(
+            clap::Arg::new("since")
+                .long("since")
+                .takes_value(true)
+                .help("point in the chain to start reading from, expects format `slot,hex-hash`"),
+        )
+        .arg(
+            clap::Arg::new("mode")
+                .long("mode")
+                .takes_value(true)
+                .possible_values(&["node", "client"]),
+        )
+        .arg(
+            clap::Arg::new("output")
+                .long("output")
+                .takes_value(true)
+                .help("path-like prefix for the log files (fallbacks to stdout output)"),
+        )
+}
